+++
title = "General Data Protection Regulation (GDPR)"
description = "General Data Protection Regulation (GDPR)"
date = "2019-08-07"
author = "Christian Decker"
+++

GDPR information are highly specific to the site. You may use a generator, e.g. 
[Datenschutz-Generator](https://datenschutz-generator.de/datenschutzerklaerung/)

